@@ -3,10 +3,11 @@
 # Copyright 2021 Graviti. Licensed under MIT License.
 #
 
-"""TensorBay dataset version control related classes."""
+"""Related methods of the TensorBay version control."""
 
-from typing import Any, Dict, Generator, Optional, Union
+from typing import Any, Callable, Dict, Generator, Optional, Union
 
+from tensorbay.client.job import SquashAndMergeJob
 from tensorbay.client.lazy import PagingList
 from tensorbay.client.requests import Client
 from tensorbay.client.status import Status
@@ -15,14 +16,7 @@ from tensorbay.exception import ResourceNotExistError, StatusError
 
 
 class VersionControlMixin:  # pylint: disable=too-many-public-methods
-    """A mixin class supporting version control methods.
-
-    Arguments:
-        _dataset_id: Dataset ID.
-        _client: The client to interact between local and TensorBay.
-        _status: The version control status of the dataset.
-
-    """
+    """A mixin class supporting version control methods."""
 
     _dataset_id: str
     _client: Client
@@ -315,67 +309,6 @@ class VersionControlMixin:  # pylint: disable=too-many-public-methods
 
         self._close_draft(number)
 
-    def squash_and_merge(
-        self,
-        title: str,
-        description: str = "",
-        *,
-        source_branch_name: str,
-        target_branch_name: Optional[str] = None,
-        strategy: Optional[str] = "abort",
-    ) -> int:
-        """Squash and merge.
-
-        Squash commits in source branch, then merge into target branch by creating a new draft.
-        If the target branch name is not given, the draft will be based on the branch name stored
-        in the dataset client. And during merging, the conflicts between branches can be resolved
-        in three different strategies: "abort", "override" and "skip".
-
-        Arguments:
-            title: The draft title.
-            description: The draft description.
-            source_branch_name: The name of the branch to be squashed.
-            target_branch_name: The target branch name of the merge operation.
-            strategy: The strategy of handling the branch conflict. There are three options:
-
-                1. "abort": abort the opetation;
-                2. "override": the squashed branch will override the target branch;
-                3. "skip": keep the origin branch.
-
-        Raises:
-            StatusError: When squashing and merging without basing on a branch.
-
-        Returns:
-            The draft number of the new draft.
-
-        """
-        if not target_branch_name:
-            target_branch_name = self._status.branch_name
-            if not target_branch_name:
-                raise StatusError(
-                    message="Squash and merge without basing on a branch is not allowed"
-                )
-            self._status.check_authority_for_commit()
-
-        post_data: Dict[str, Any] = {
-            "title": title,
-            "sourceBranchName": source_branch_name,
-            "targetBranchName": target_branch_name,
-            "strategy": strategy,
-        }
-
-        if description:
-            post_data["description"] = description
-
-        response = self._client.open_api_do(
-            "POST", "squashAndMerge", self._dataset_id, json=post_data
-        )
-        draft_number: int = response.json()["draftNumber"]
-
-        self._status.checkout(draft_number=draft_number)
-        self._status.branch_name = target_branch_name
-        return draft_number
-
     def get_commit(self, revision: Optional[str] = None) -> Commit:
         """Get the certain commit with the given revision.
 
@@ -582,3 +515,240 @@ class VersionControlMixin:  # pylint: disable=too-many-public-methods
         delete_data: Dict[str, Any] = {"name": name}
 
         self._client.open_api_do("DELETE", "tags", self._dataset_id, json=delete_data)
+
+
+class JobMixin:
+    """A mixin class supporting asynchronous jobs."""
+
+    _dataset_id: str
+    _client: Client
+    _status: Status
+
+    def _create_job(
+        self,
+        title: str,
+        job_type: str,
+        arguments: Dict[str, Any],
+        description: str = "",
+    ) -> Dict[str, Any]:
+        """Create a :class:`Job`.
+
+        Arguments:
+            title: The Job title.
+            job_type: The type of Job.
+            arguments: The arguments dict of the specific job.
+            description: The Job description.
+
+        Returns:
+            The info of the job.
+
+        """
+        post_data: Dict[str, Any] = {"title": title, "jobType": job_type, "arguments": arguments}
+        if description:
+            post_data["description"] = description
+
+        response: Dict[str, Any] = self._client.open_api_do(
+            "POST", "jobs", self._dataset_id, json=post_data
+        ).json()
+
+        response.update(
+            title=title,
+            arguments=arguments,
+            status="QUEUING",
+            description=description,
+        )
+        return response
+
+    def _get_job(self, job_id: str) -> Dict[str, Any]:
+        """Get a :class:`Job`.
+
+        Arguments:
+            job_id: The Job id.
+
+        Returns:
+            The info of Job.
+
+        """
+        return self._client.open_api_do(  # type: ignore[no-any-return]
+            "GET", f"jobs/{job_id}", self._dataset_id
+        ).json()
+
+    def _list_jobs(
+        self,
+        job_type: str,
+        status: Optional[str] = None,
+        offset: int = 0,
+        limit: int = 128,
+    ) -> Dict[str, Any]:
+        """Get a dict containing the information of :class:`Job` list.
+
+        Arguments:
+            job_type: Type of the Job.
+            status: The Job status which includes "QUEUING", "PROCESSING", "SUCCESS", "FAILED",
+                    "ABORTED" and None. None means all kinds of status.
+            offset: The offset of the page.
+            limit: The limit of the page.
+
+        Returns:
+            A dict containing the information of Job list.
+
+        """
+        params = {"jobType": job_type, "status": status, "offset": offset, "limit": limit}
+
+        response = self._client.open_api_do("GET", "jobs", self._dataset_id, params=params)
+        return response.json()  # type: ignore[no-any-return]
+
+    def delete_job(self, job_id: str) -> None:
+        """Delete a :class:`Job`.
+
+        Arguments:
+            job_id: The Job id.
+
+        """
+        self._client.open_api_do("DELETE", f"jobs/{job_id}", self._dataset_id)
+
+
+class SquashAndMerge(JobMixin):
+    """This class defines :class:`SquashAndMerge`.
+
+    Arguments:
+        client: The :class:`~tensorbay.client.requests.Client`.
+        dataset_id: Dataset ID.
+        status: The version control status of the dataset.
+        draft_getter: The function to get draft by draft_number.
+
+    """
+
+    _JOB_TYPE = "squashAndMerge"
+
+    def __init__(
+        self,
+        client: Client,
+        dataset_id: str,
+        status: Status,
+        draft_getter: Callable[[int], Draft],
+    ) -> None:
+        self._client = client
+        self._dataset_id = dataset_id
+        self._status = status
+        self._draft_getter = draft_getter
+
+    def _generate_jobs(
+        self,
+        status: Optional[str] = None,
+        offset: int = 0,
+        limit: int = 128,
+    ) -> Generator[SquashAndMergeJob, None, int]:
+        response = self._list_jobs(self._JOB_TYPE, status, offset, limit)
+        for item in response["jobs"]:
+            yield SquashAndMergeJob.from_response_body(
+                item,
+                dataset_id=self._dataset_id,
+                client=self._client,
+                job_updater=self._get_job,
+                draft_getter=self._draft_getter,
+            )
+
+        return response["totalCount"]  # type: ignore[no-any-return]
+
+    def create_job(
+        self,
+        title: str = "",
+        description: str = "",
+        *,
+        draft_title: str,
+        source_branch_name: str,
+        target_branch_name: Optional[str] = None,
+        draft_description: str = "",
+        strategy: Optional[str] = "abort",
+    ) -> SquashAndMergeJob:
+        """Create a :class:`SquashAndMergeJob`.
+
+        Squash commits in source branch, then merge into target branch by creating a new draft.
+        If the target branch name is not given, the draft will be based on the branch name stored
+        in the dataset client. And during merging, the conflicts between branches can be resolved
+        in three different strategies: "abort", "override" and "skip".
+
+        Arguments:
+            title: The SquashAndMergeJob title.
+            description: The SquashAndMergeJob description.
+            draft_title: The draft title.
+            source_branch_name: The name of the branch to be squashed.
+            target_branch_name: The target branch name of the merge operation.
+            draft_description: The draft description.
+            strategy: The strategy of handling the branch conflict. There are three options:
+
+                1. "abort": abort the opetation;
+                2. "override": the squashed branch will override the target branch;
+                3. "skip": keep the origin branch.
+
+        Raises:
+            StatusError: When squashing and merging without basing on a branch.
+
+        Returns:
+            The SquashAndMergeJob.
+
+        """
+        if not target_branch_name:
+            target_branch_name = self._status.branch_name
+            if not target_branch_name:
+                raise StatusError(
+                    message="Squash and merge without basing on a branch is not allowed"
+                )
+            self._status.check_authority_for_commit()
+
+        if not title:
+            title = f"{source_branch_name}->{target_branch_name}({strategy})"
+
+        arguments = {
+            "title": draft_title,
+            "sourceBranchName": source_branch_name,
+            "targetBranchName": target_branch_name,
+            "strategy": strategy,
+        }
+        if draft_description:
+            arguments["description"] = draft_description
+
+        job_info = self._create_job(title, self._JOB_TYPE, arguments, description)
+        return SquashAndMergeJob.from_response_body(
+            job_info,
+            dataset_id=self._dataset_id,
+            client=self._client,
+            job_updater=self._get_job,
+            draft_getter=self._draft_getter,
+        )
+
+    def get_job(self, job_id: str) -> SquashAndMergeJob:
+        """Get a :class:`SquashAndMergeJob`.
+
+        Arguments:
+            job_id: The SquashAndMergeJob id.
+
+        Returns:
+            The SquashAndMergeJob.
+
+        """
+        job_info = self._get_job(job_id)
+        return SquashAndMergeJob.from_response_body(
+            job_info,
+            dataset_id=self._dataset_id,
+            client=self._client,
+            job_updater=self._get_job,
+            draft_getter=self._draft_getter,
+        )
+
+    def list_jobs(self, status: Optional[str] = None) -> PagingList[SquashAndMergeJob]:
+        """List the SquashAndMergeJob.
+
+        Arguments:
+            status: The SquashAndMergeJob status which includes "QUEUING", "PROCESSING", "SUCCESS",
+                    "FAIL", "ABORT" and None. None means all kinds of status.
+
+        Returns:
+            The PagingList of SquashAndMergeJob.
+
+        """
+        return PagingList(
+            lambda offset, limit: self._generate_jobs(status, offset, limit),
+            128,
+        )
