@@ -16,14 +16,14 @@ basic checking and catalog checking.
 from collections import OrderedDict
 from typing import Any, Callable, List, TypeVar
 
-from ..utility import UserMutableMapping, UserSequence
+from tensorbay.utility import UserMutableMapping, UserSequence
 
 
-class Error:  # pylint: disable=too-few-public-methods
+class Error:
     """Base class of healthcheck errors."""
 
     def __str__(self) -> str:
-        ...
+        return ""
 
 
 class _ErrorContext:
@@ -100,7 +100,7 @@ class _ErrorDict(UserMutableMapping[_T, _ErrorSection], _ErrorContext):
         return value
 
 
-class HealthReport:  # pylint: disable=too-few-public-methods
+class HealthReport:
     """:class:`HealthReport` is the result of the healthcheck, which contains all the errors."""
 
     def __init__(self) -> None:
