@@ -60,14 +60,14 @@ def BioIDFace(path: str) -> Dataset:
 
 def _get_label(eye_keypoints_path: str, face_keypoints_path: str) -> List[LabeledKeypoints2D]:
     eye_keypoints = LabeledKeypoints2D(category="EyePosition")
-    with open(eye_keypoints_path, "r", encoding="utf-8") as fp:
+    with open(eye_keypoints_path, encoding="utf-8") as fp:
         fp.readline()  # The first line is like: #LX     LY      RX      RY
         lx, ly, rx, ry = map(int, fp.readline().split())
         eye_keypoints.append(Keypoint2D(lx, ly))
         eye_keypoints.append(Keypoint2D(rx, ry))
 
     face_keypoints = LabeledKeypoints2D(category="Face")
-    with open(face_keypoints_path, "r", encoding="utf-8") as fp:
+    with open(face_keypoints_path, encoding="utf-8") as fp:
         # The annotation file is like:
         #  1 version: 1
         #  2 n_points: 20
